==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/gl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Falta o contrasinal da chave de recuperación",
    "Please repeat the recovery key password" : "Repita o contrasinal da chave de recuperación",
    "Repeated recovery key password does not match the provided recovery key password" : "A repetición do contrasinal da chave de recuperación non coincide co contrasinal da chave de recuperación fornecido",
    "Recovery key successfully enabled" : "Activada satisfactoriamente a chave de recuperación",
    "Could not enable recovery key. Please check your recovery key password!" : "Non foi posíbel activar a chave de recuperación. Comprobe o contrasinal da chave de recuperación!",
    "Recovery key successfully disabled" : "Desactivada satisfactoriamente a chave de recuperación",
    "Could not disable recovery key. Please check your recovery key password!" : "Non foi posíbel desactivar a chave de recuperación. Comprobe o contrasinal da chave de recuperación!",
    "Missing parameters" : "Faltan os parámetros",
    "Please provide the old recovery password" : "Introduza o antigo contrasinal de recuperación",
    "Please provide a new recovery password" : "Introduza a nova chave de recuperación",
    "Please repeat the new recovery password" : "Repita o novo contrasinal de recuperación",
    "Password successfully changed." : "O contrasinal foi cambiado satisfactoriamente",
    "Could not change the password. Maybe the old password was not correct." : "Non foi posíbel cambiar o contrasinal. Probabelmente o contrasinal antigo non é o  correcto.",
    "Recovery Key disabled" : "Desactivada a chave de recuperación",
    "Recovery Key enabled" : "Activada a chave de recuperación",
    "Could not enable the recovery key, please try again or contact your administrator" : "Non foi posíbel activar a chave de recuperación, ténteo de novo ou póñase en contacto co administrador.",
    "Could not update the private key password." : "Non foi posíbel actualizar o contrasinal da chave privada.",
    "The old password was not correct, please try again." : "O contrasinal antigo non é correcto, ténteo de novo.",
    "The current log-in password was not correct, please try again." : "O actual contrasinal de acceso non é correcto, ténteo de novo.",
    "Private key password successfully updated." : "A chave privada foi actualizada correctamente.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "É necesario migrar as súas chaves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo. Execute «occ encryption:migrate» ou contacte co administrador",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Non foi posíbel descifrar o ficheiro, probabelmente tratase dun ficheiro compartido. Pídalle ao propietario do ficheiro que  volva compartir o ficheiro con vostede.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Non foi posíbel ler o ficheiro, probabelmente tratase dun ficheiro compartido. Pídalle ao propietario do ficheiro que  volva compartir o ficheiro con vostede.",
    "The share will expire on %s." : "Esta compartición caduca o %s.",
    "Cheers!" : "Saúdos!",
    "Enable recovery key" : "Activar a chave de recuperación",
    "Disable recovery key" : "Desactivar a chave de recuperación",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperación é unha chave de cifrado adicional que se utiliza para cifrar ficheiros. Permite a recuperación de ficheiros dun usuario se o usuario esquece o seu contrasinal.",
    "Recovery key password" : "Contrasinal da chave de recuperación",
    "Repeat recovery key password" : "Repita o contrasinal da chave de recuperación",
    "Change recovery key password:" : "Cambiar o contrasinal da chave de la recuperación:",
    "Old recovery key password" : "Contrasinal antigo da chave de recuperación",
    "New recovery key password" : "Novo contrasinal da chave de recuperación",
    "Repeat new recovery key password" : "Repita o novo contrasinal da chave de recuperación",
    "Change Password" : "Cambiar o contrasinal",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "A aplicación de cifrado está activada, mais as chaves non foron preparadas, saia da sesión e volva a acceder de novo",
    "Your private key password no longer matches your log-in password." : "O seu contrasinal da chave privada non coincide co seu contrasinal de acceso.",
    "Set your old private key password to your current log-in password:" : "Estabeleza o seu contrasinal antigo da chave de recuperación ao seu contrasinal de acceso actual:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se non lembra o seu antigo contrasinal pode pedírllelo ao seu administrador para recuperar os seus ficheiros.",
    "Old log-in password" : "Contrasinal antigo de acceso",
    "Current log-in password" : "Contrasinal actual de acceso",
    "Update Private Key Password" : "Actualizar o contrasinal da chave privada",
    "Enable password recovery:" : "Activar o  contrasinal de recuperación:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ao activar esta opción permitiráselle volver a obter acceso aos ficheiros cifrados no caso de perda do contrasinal",
    "Enabled" : "Activado",
    "Disabled" : "Desactivado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/gl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Falta o contrasinal da chave de recuperación",
    "Please repeat the recovery key password" : "Repita o contrasinal da chave de recuperación",
    "Repeated recovery key password does not match the provided recovery key password" : "A repetición do contrasinal da chave de recuperación non coincide co contrasinal da chave de recuperación fornecido",
    "Recovery key successfully enabled" : "Activada satisfactoriamente a chave de recuperación",
    "Could not enable recovery key. Please check your recovery key password!" : "Non foi posíbel activar a chave de recuperación. Comprobe o contrasinal da chave de recuperación!",
    "Recovery key successfully disabled" : "Desactivada satisfactoriamente a chave de recuperación",
    "Could not disable recovery key. Please check your recovery key password!" : "Non foi posíbel desactivar a chave de recuperación. Comprobe o contrasinal da chave de recuperación!",
    "Missing parameters" : "Faltan os parámetros",
    "Please provide the old recovery password" : "Introduza o antigo contrasinal de recuperación",
    "Please provide a new recovery password" : "Introduza a nova chave de recuperación",
    "Please repeat the new recovery password" : "Repita o novo contrasinal de recuperación",
    "Password successfully changed." : "O contrasinal foi cambiado satisfactoriamente",
    "Could not change the password. Maybe the old password was not correct." : "Non foi posíbel cambiar o contrasinal. Probabelmente o contrasinal antigo non é o  correcto.",
    "Recovery Key disabled" : "Desactivada a chave de recuperación",
    "Recovery Key enabled" : "Activada a chave de recuperación",
    "Could not enable the recovery key, please try again or contact your administrator" : "Non foi posíbel activar a chave de recuperación, ténteo de novo ou póñase en contacto co administrador.",
    "Could not update the private key password." : "Non foi posíbel actualizar o contrasinal da chave privada.",
    "The old password was not correct, please try again." : "O contrasinal antigo non é correcto, ténteo de novo.",
    "The current log-in password was not correct, please try again." : "O actual contrasinal de acceso non é correcto, ténteo de novo.",
    "Private key password successfully updated." : "A chave privada foi actualizada correctamente.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "É necesario migrar as súas chaves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo. Execute «occ encryption:migrate» ou contacte co administrador",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Non foi posíbel descifrar o ficheiro, probabelmente tratase dun ficheiro compartido. Pídalle ao propietario do ficheiro que  volva compartir o ficheiro con vostede.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Non foi posíbel ler o ficheiro, probabelmente tratase dun ficheiro compartido. Pídalle ao propietario do ficheiro que  volva compartir o ficheiro con vostede.",
    "The share will expire on %s." : "Esta compartición caduca o %s.",
    "Cheers!" : "Saúdos!",
    "Enable recovery key" : "Activar a chave de recuperación",
    "Disable recovery key" : "Desactivar a chave de recuperación",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperación é unha chave de cifrado adicional que se utiliza para cifrar ficheiros. Permite a recuperación de ficheiros dun usuario se o usuario esquece o seu contrasinal.",
    "Recovery key password" : "Contrasinal da chave de recuperación",
    "Repeat recovery key password" : "Repita o contrasinal da chave de recuperación",
    "Change recovery key password:" : "Cambiar o contrasinal da chave de la recuperación:",
    "Old recovery key password" : "Contrasinal antigo da chave de recuperación",
    "New recovery key password" : "Novo contrasinal da chave de recuperación",
    "Repeat new recovery key password" : "Repita o novo contrasinal da chave de recuperación",
    "Change Password" : "Cambiar o contrasinal",
    "Your private key password no longer matches your log-in password." : "O seu contrasinal da chave privada non coincide co seu contrasinal de acceso.",
    "Set your old private key password to your current log-in password:" : "Estabeleza o seu contrasinal antigo da chave de recuperación ao seu contrasinal de acceso actual:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se non lembra o seu antigo contrasinal pode pedírllelo ao seu administrador para recuperar os seus ficheiros.",
    "Old log-in password" : "Contrasinal antigo de acceso",
    "Current log-in password" : "Contrasinal actual de acceso",
    "Update Private Key Password" : "Actualizar o contrasinal da chave privada",
    "Enable password recovery:" : "Activar o  contrasinal de recuperación:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ao activar esta opción permitiráselle volver a obter acceso aos ficheiros cifrados no caso de perda do contrasinal",
    "Enabled" : "Activado",
    "Disabled" : "Desactivado",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "A aplicación de cifrado está activada, mais as chaves non foron preparadas, saia da sesión e volva a acceder de novo"
},
"nplurals=2; plural=(n != 1);");
